@@ -220,13 +220,13 @@ def _get_custom_criteria(
     return list(results)
 
 
-def _get_axis_coord(var: Union[DataArray, Dataset], key: str) -> List[str]:
+def _get_axis_coord(obj: Union[DataArray, Dataset], key: str) -> List[str]:
     """
     Translate from axis or coord name to variable name
 
     Parameters
     ----------
-    var : DataArray, Dataset
+    obj : DataArray, Dataset
         DataArray belonging to the coordinate to be checked
     key : str, ["X", "Y", "Z", "T", "longitude", "latitude", "vertical", "time"]
         key to check for.
@@ -260,25 +260,29 @@ def _get_axis_coord(var: Union[DataArray, Dataset], key: str) -> List[str]:
         )
 
     search_in = set()
-    if "coordinates" in var.encoding:
-        search_in.update(var.encoding["coordinates"].split(" "))
-    if "coordinates" in var.attrs:
-        search_in.update(var.attrs["coordinates"].split(" "))
+    if "coordinates" in obj.encoding:
+        search_in.update(obj.encoding["coordinates"].split(" "))
+    if "coordinates" in obj.attrs:
+        search_in.update(obj.attrs["coordinates"].split(" "))
     if not search_in:
-        search_in = set(var.coords)
+        search_in = set(obj.coords)
 
     # maybe only do this for key in _AXIS_NAMES?
-    search_in.update(var.indexes)
+    search_in.update(obj.indexes)
 
+    search_in = search_in & set(obj.coords)
     results: Set = set()
     for coord in search_in:
+        var = obj.coords[coord]
         if key in coordinate_criteria:
             for criterion, expected in coordinate_criteria[key].items():
-                if (
-                    coord in var.coords
-                    and var.coords[coord].attrs.get(criterion, None) in expected
-                ):
+                if var.attrs.get(criterion, None) in expected:
                     results.update((coord,))
+                if criterion == "units":
+                    # deal with pint-backed objects
+                    units = getattr(var.data, "units", None)
+                    if units in expected:
+                        results.update((coord,))
     return list(results)
 
 
@@ -344,7 +348,7 @@ def _get_bounds(obj: Union[DataArray, Dataset], key: str) -> List[str]:
 def _get_with_standard_name(
     obj: Union[DataArray, Dataset], name: Union[str, List[str]]
 ) -> List[str]:
-    """ returns a list of variable names with standard name == name. """
+    """returns a list of variable names with standard name == name."""
     if name is None:
         return []
 
@@ -624,7 +628,7 @@ def _getitem(
         # with a scalar key. Hopefully these will soon get decoded to IntervalIndex
         # and we can move on...
         if scalar_key:
-            bounds = set([obj[k].attrs.get("bounds", None) for k in names])
+            bounds = {obj[k].attrs.get("bounds", None) for k in names}
             names = set(names) - bounds
         return names
 
@@ -732,7 +736,7 @@ def _getitem(
         )
 
 
-def _possible_x_y_plot(obj, key):
+def _possible_x_y_plot(obj, key, skip=None):
     """Guesses a name for an x/y variable if possible."""
     # in priority order
     x_criteria = [
@@ -755,11 +759,20 @@ def _possible_x_y_plot(obj, key):
         from xarray.core.utils import is_scalar
 
         for attr, key in criteria:
-            value = getattr(accessor, attr).get(key)
-            if not value or len(value) > 1:
+            values = getattr(accessor, attr).get(key)
+            ax_coord_name = getattr(accessor, attr).get(key)
+            if not values:
                 continue
-            if not is_scalar(accessor._obj[value[0]]):
-                return value[0]
+            elif ax_coord_name:
+                values = [v for v in values if v in ax_coord_name]
+
+            values = [v for v in values if v != skip]
+            if len(values) == 1 and not is_scalar(accessor._obj[values[0]]):
+                return values[0]
+            else:
+                for v in values:
+                    if not is_scalar(accessor._obj[v]):
+                        return v
         return None
 
     if key == "x":
@@ -821,9 +834,9 @@ class _CFWrappedPlotMethods:
 
         @functools.wraps(func)
         def _plot_wrapper(*args, **kwargs):
-            def _process_x_or_y(kwargs, key):
+            def _process_x_or_y(kwargs, key, skip=None):
                 if key not in kwargs:
-                    kwargs[key] = _possible_x_y_plot(self._obj, key)
+                    kwargs[key] = _possible_x_y_plot(self._obj, key, skip)
 
                 value = kwargs.get(key)
                 if value:
@@ -843,13 +856,15 @@ class _CFWrappedPlotMethods:
                 and (kwargs.get("hue") or self._obj.ndim == 1)
             )
             if is_line_plot:
-                if not kwargs.get("hue"):
-                    kwargs = _process_x_or_y(kwargs, "x")
+                hue = kwargs.get("hue")
+                if "x" not in kwargs and "y" not in kwargs:
+                    kwargs = _process_x_or_y(kwargs, "x", skip=hue)
                     if not kwargs.get("x"):
-                        kwargs = _process_x_or_y(kwargs, "y")
+                        kwargs = _process_x_or_y(kwargs, "y", skip=hue)
+
             else:
-                kwargs = _process_x_or_y(kwargs, "x")
-                kwargs = _process_x_or_y(kwargs, "y")
+                kwargs = _process_x_or_y(kwargs, "x", skip=kwargs.get("y"))
+                kwargs = _process_x_or_y(kwargs, "y", skip=kwargs.get("x"))
 
             return func(*args, **kwargs)
 
@@ -882,15 +897,134 @@ class _CFWrappedPlotMethods:
         )
 
 
+def create_flag_dict(da):
+    if not da.cf.is_flag_variable:
+        raise ValueError(
+            "Comparisons are only supported for DataArrays that represent CF flag variables."
+            ".attrs must contain 'flag_values' and 'flag_meanings'"
+        )
+
+    flag_meanings = da.attrs["flag_meanings"].split(" ")
+    flag_values = da.attrs["flag_values"]
+    # TODO: assert flag_values is iterable
+    assert len(flag_values) == len(flag_meanings)
+    return dict(zip(flag_meanings, flag_values))
+
+
 class CFAccessor:
     """
     Common Dataset and DataArray accessor functionality.
     """
 
-    def __init__(self, da):
-        self._obj = da
+    def __init__(self, obj):
+        self._obj = obj
         self._all_cell_measures = None
 
+    def _assert_valid_other_comparison(self, other):
+        flag_dict = create_flag_dict(self._obj)
+        if other not in flag_dict:
+            raise ValueError(
+                f"Did not find flag value meaning [{other}] in known flag meanings: [{flag_dict.keys()!r}]"
+            )
+        return flag_dict
+
+    def __eq__(self, other):
+        """
+        Compare flag values against `other`.
+
+        `other` must be in the 'flag_meanings' attribute.
+        `other` is mapped to the corresponding value in the 'flag_values' attribute, and then
+        compared.
+        """
+        flag_dict = self._assert_valid_other_comparison(other)
+        return self._obj == flag_dict[other]
+
+    def __ne__(self, other):
+        """
+        Compare flag values against `other`.
+
+        `other` must be in the 'flag_meanings' attribute.
+        `other` is mapped to the corresponding value in the 'flag_values' attribute, and then
+        compared.
+        """
+        flag_dict = self._assert_valid_other_comparison(other)
+        return self._obj != flag_dict[other]
+
+    def __lt__(self, other):
+        """
+        Compare flag values against `other`.
+
+        `other` must be in the 'flag_meanings' attribute.
+        `other` is mapped to the corresponding value in the 'flag_values' attribute, and then
+        compared.
+        """
+        flag_dict = self._assert_valid_other_comparison(other)
+        return self._obj < flag_dict[other]
+
+    def __le__(self, other):
+        """
+        Compare flag values against `other`.
+
+        `other` must be in the 'flag_meanings' attribute.
+        `other` is mapped to the corresponding value in the 'flag_values' attribute, and then
+        compared.
+        """
+        flag_dict = self._assert_valid_other_comparison(other)
+        return self._obj <= flag_dict[other]
+
+    def __gt__(self, other):
+        """
+        Compare flag values against `other`.
+
+        `other` must be in the 'flag_meanings' attribute.
+        `other` is mapped to the corresponding value in the 'flag_values' attribute, and then
+        compared.
+        """
+        flag_dict = self._assert_valid_other_comparison(other)
+        return self._obj > flag_dict[other]
+
+    def __ge__(self, other):
+        """
+        Compare flag values against `other`.
+
+        `other` must be in the 'flag_meanings' attribute.
+        `other` is mapped to the corresponding value in the 'flag_values' attribute, and then
+        compared.
+        """
+        flag_dict = self._assert_valid_other_comparison(other)
+        return self._obj >= flag_dict[other]
+
+    def isin(self, test_elements):
+        """Test each value in the array for whether it is in test_elements.
+
+        Parameters
+        ----------
+        test_elements : array_like, 1D
+            The values against which to test each value of `element`.
+            These must be in "flag_meanings" attribute, and are mapped
+            to the corresponding value in "flag_values" before passing
+            that on to DataArray.isin.
+
+
+        Returns
+        -------
+        isin : DataArray
+            Has the same type and shape as this object, but with a bool dtype.
+        """
+        if not isinstance(self._obj, DataArray):
+            raise ValueError(
+                ".cf.isin is only supported on DataArrays that contain CF flag attributes."
+            )
+        flag_dict = create_flag_dict(self._obj)
+        mapped_test_elements = []
+        for elem in test_elements:
+            if elem not in flag_dict:
+                raise ValueError(
+                    f"Did not find flag value meaning [{elem}] in known flag meanings: [{flag_dict.keys()!r}]"
+                )
+            mapped_test_elements.append(flag_dict[elem])
+        return self._obj.isin(mapped_test_elements)
+
     def _get_all_cell_measures(self):
         """
         Get all cell measures defined in the object, adding CF pre-defined measures.
@@ -911,9 +1045,9 @@ class CFAccessor:
     ):
         """
         Processes a function's signature, args, kwargs:
-        1. Binds *args so that everthing is a Mapping from kwarg name to values
-        2. Calls _rewrite_values to rewrite any special CF names to normal xarray names.
-           This uses key_mappers
+        1. Binds ``*args`` so that everthing is a Mapping from kwarg name to values
+        2. Calls ``_rewrite_values`` to rewrite any special CF names to normal xarray names.
+           This uses ``key_mappers``
         3. Unpacks arguments if necessary before returning them.
         """
         sig = inspect.signature(func, follow_wrapped=False)
@@ -999,12 +1133,12 @@ class CFAccessor:
                 # e.g. .isel(X=5) → .isel(xi_rho=5, xi_u=5, xi_v=5, xi_psi=5)
                 # where xi_* have attrs["axis"] = "X"
                 updates[key] = ChainMap(
-                    *[
+                    *(
                         dict.fromkeys(
                             apply_mapper(mappers, self._obj, k, False, [k]), v
                         )
                         for k, v in value.items()
-                    ]
+                    )
                 )
 
             elif value is Ellipsis:
@@ -1126,7 +1260,12 @@ class CFAccessor:
 
             return "\n".join(rows) + "\n"
 
-        text = "Coordinates:"
+        if isinstance(self._obj, DataArray) and self._obj.cf.is_flag_variable:
+            flag_dict = create_flag_dict(self._obj)
+            text = f"CF Flag variable with mapping:\n\t{flag_dict!r}\n\n"
+        else:
+            text = ""
+        text += "Coordinates:"
         text += make_text_section("CF Axes", "axes", coords, _AXIS_NAMES)
         text += make_text_section("CF Coordinates", "coordinates", coords, _COORD_NAMES)
         text += make_text_section(
@@ -2053,4 +2192,18 @@ class CFDataArrayAccessor(CFAccessor):
 
         return _getitem(self, key)
 
-    pass
+    @property
+    def is_flag_variable(self):
+        """
+        Returns True if the DataArray satisfies CF conventions for flag variables.
+
+        Flag masks are not supported yet.
+        """
+        if (
+            isinstance(self._obj, DataArray)
+            and "flag_meanings" in self._obj.attrs
+            and "flag_values" in self._obj.attrs
+        ):
+            return True
+        else:
+            return False
