@@ -1,5 +1,7 @@
+import importlib
 import re
 from contextlib import contextmanager
+from distutils import version
 
 import dask
 import pytest
@@ -39,3 +41,26 @@ class CountingScheduler:
 def raise_if_dask_computes(max_computes=0):
     scheduler = CountingScheduler(max_computes)
     return dask.config.set(scheduler=scheduler)
+
+
+def _importorskip(modname, minversion=None):
+    try:
+        mod = importlib.import_module(modname)
+        has = True
+        if minversion is not None:
+            if LooseVersion(mod.__version__) < LooseVersion(minversion):
+                raise ImportError("Minimum version not satisfied")
+    except ImportError:
+        has = False
+    func = pytest.mark.skipif(not has, reason=f"requires {modname}")
+    return has, func
+
+
+def LooseVersion(vstring):
+    # Our development version is something like '0.10.9+aac7bfc'
+    # This function just ignored the git commit id.
+    vstring = vstring.split("+")[0]
+    return version.LooseVersion(vstring)
+
+
+has_pint, requires_pint = _importorskip("pint")
