@@ -17,6 +17,7 @@ from cf_xarray.utils import parse_cf_standard_name_table
 from ..datasets import (
     airds,
     anc,
+    basin,
     ds_no_attrs,
     forecast,
     mollwds,
@@ -24,7 +25,7 @@ from ..datasets import (
     popds,
     romsds,
 )
-from . import raise_if_dask_computes
+from . import raise_if_dask_computes, requires_pint
 
 mpl.use("Agg")
 
@@ -128,6 +129,9 @@ def test_repr():
     """
     assert actual == dedent(expected)
 
+    # Flag DataArray
+    assert "CF Flag variable" in repr(basin.cf)
+
 
 def test_axes():
     expected = dict(T=["time"], X=["lon"], Y=["lat"])
@@ -149,6 +153,19 @@ def test_coordinates():
     assert actual == expected
 
 
+@requires_pint
+def test_coordinates_quantified():
+    # note: import order is important
+    from .. import units  # noqa
+
+    pytest.importorskip("pint_xarray")
+
+    quantified = popds.pint.quantify()
+    assert_identical(
+        quantified.cf[["latitude"]].pint.dequantify(), popds.cf[["latitude"]]
+    )
+
+
 def test_cell_measures():
     ds = airds.copy(deep=True)
     ds["foo"] = xr.DataArray(ds["cell_area"], attrs=dict(standard_name="foo_std_name"))
@@ -479,9 +496,9 @@ def test_dataarray_plot():
     np.testing.assert_equal(rv[0].get_xdata(), obj.lon.data)
     plt.close()
 
-    # rv = obj.cf.isel(T=1, Y=[0, 1, 2]).cf.plot(hue="Y")
-    # np.testing.assert_equal(rv[0].get_xdata(), obj.lon.data)
-    # plt.close()
+    rv = obj.cf.isel(T=1, Y=[0, 1, 2]).cf.plot(hue="Y")
+    np.testing.assert_equal(rv[0].get_xdata(), obj.lon.data)
+    plt.close()
 
     rv = obj.cf.isel(T=1, Y=[0, 1, 2]).cf.plot.line()
     np.testing.assert_equal(rv[0].get_xdata(), obj.lon.data)
@@ -1376,3 +1393,35 @@ def test_add_canonical_attributes(override, skip, verbose, capsys):
 
         cf_da.attrs.pop("history")
         assert_identical(cf_da, cf_ds["air"])
+
+
+@pytest.mark.parametrize("op", ["ge", "gt", "eq", "ne", "le", "lt"])
+def test_flag_features(op):
+    actual = getattr(basin.cf, f"__{op}__")("atlantic_ocean")
+    expected = getattr(basin, f"__{op}__")(1)
+    assert_identical(actual, expected)
+
+
+def test_flag_isin():
+    actual = basin.cf.isin(["atlantic_ocean", "pacific_ocean"])
+    expected = basin.isin([1, 2])
+    assert_identical(actual, expected)
+
+
+def test_flag_errors():
+    with pytest.raises(ValueError):
+        basin.cf.isin(["arctic_ocean"])
+
+    with pytest.raises(ValueError):
+        basin.cf == "arctic_ocean"
+
+    ds = xr.Dataset({"basin": basin})
+    with pytest.raises(ValueError):
+        ds.cf.isin(["atlantic_ocean"])
+
+    basin.attrs.pop("flag_values")
+    with pytest.raises(ValueError):
+        basin.cf.isin(["pacific_ocean"])
+
+    with pytest.raises(ValueError):
+        basin.cf == "pacific_ocean"
